@@ -7,11 +7,11 @@ Elive - Elluminate Live! (c) SDK bindings
 
 =head1 VERSION
 
-Version 0.68
+Version 0.69
 
 =cut
 
-our $VERSION = '0.68';
+our $VERSION = '0.69';
 
 use Class::Data::Inheritable;
 use base qw{Class::Data::Inheritable};
@@ -56,9 +56,9 @@ participants:
 Elive is a set of Perl bindings and entity definitions for the Elluminate
 I<Live!> SDK.
 
-The Elluminate SDK runs as a SOAP service and can be used to automate
-the raising meetings and launching of meetings; as well as managing meetings,
-users, groups, preloads, recordings and other related entities.
+The Elluminate SDK runs as a SOAP service and can be used to automate the
+raising, launching and management of meetings; and other related entities,
+including users, groups, preloads, recordings and others.
 
 =head1 BACKGROUND
 
@@ -107,9 +107,7 @@ See also Elive::Connection.
 =cut
 
 sub connect {
-
-    my $class = shift;
-    my ($url, $login_name, $pass) = @_;
+    my ($class, $url, $login_name, $pass) = @_;
 
     die "usage: ${class}->new(url, login_name[, pass])"
 	unless ($class && $url && $login_name);
@@ -154,8 +152,7 @@ Returns the login user for the default connection.
 =cut
 
 sub login {
-    my $class = shift;
-    my %opt = @_;
+    my ($class, %opt) = @_;
 
     my $connection = $opt{connection} || $class->connection;
 
@@ -172,8 +169,7 @@ Returns the server details for the default connection.
 =cut
 
 sub server_details {
-    my $class = shift;
-    my %opt = @_;
+    my ($class, %opt) = @_;
 
     my $connection = $opt{connection} || $class->connection;
 
@@ -191,15 +187,14 @@ do this prior to exiting your program.
 =cut
 
 sub disconnect {
-    my $class = shift;
-    my %opt = @_;
+    my ($class, %opt) = @_;
 
     if (my $connection = $opt{connection} || $class->connection) {
 	$connection->disconnect;
 	$class->connection(undef);
     }
 
-    return undef;
+    return;
 }
 
 =head2 debug
@@ -216,10 +211,10 @@ sub disconnect {
 =cut
 
 sub debug {
-    my $class = shift;
+    my ($class, $level) = @_;
 
-    if (@_) {
-	$DEBUG = shift || 0;
+    if (defined $level) {
+	$DEBUG = $level;
     }
 
     return $DEBUG || 0;
@@ -398,6 +393,7 @@ sub has_metadata {
 sub DESTROY {
     my $self = shift;
     delete  $Meta_Data{Scalar::Util::refaddr($self)};
+    return;
 }
 
 {
