@@ -3,6 +3,7 @@ use warnings; use strict;
 
 use Class::Accessor;
 use Class::Data::Inheritable;
+use HTML::Entities;
 
 use base qw{Class::Accessor};
 
@@ -71,7 +72,7 @@ connectivity and authentication details.
 =cut
 
 sub connect {
-    my ($class, $url,  $user, $pass, %opt) = @_;
+    my ($class, $url, $user, $pass, %opt) = @_;
 
     $url =~ s{/$}{};
 
@@ -127,6 +128,8 @@ sub disconnect {
 
     $self->_server_details(undef);
     $self->_login(undef);
+
+    return;
 }
 
 =head2 call
@@ -139,13 +142,7 @@ SOAP::SOM object.
 =cut
 
 sub call {
-    my $self = shift;
-    my $cmd = shift;
-
-    die "usage: \$obj->call($cmd , %params])"
-	unless $cmd && !(@_ % 2);
-
-    my %params = @_;
+    my ($self, $cmd, %params) = @_;
 
     $params{adapter} ||= 'default';
 
@@ -183,7 +180,7 @@ Returns the login user as an object of type L<Elive::Entity::User>.
 =cut
 
 sub login {
-    my $self = shift;
+    my ($self) = @_;
 
     my $login_entity = $self->_login;
 
@@ -274,6 +271,7 @@ EOD
 
 sub DESTROY {
     shift->disconnect;
+    return;
 }
 
 =head1 SEE ALSO
