@@ -4,8 +4,7 @@ use warnings; use strict;
 use Mouse;
 use Mouse::Util::TypeConstraints;
 
-use Elive::Struct;
-use base qw{Elive::Struct};
+extends 'Elive::Struct';
 
 use Scalar::Util;
 
@@ -25,6 +24,10 @@ has 'role' => (is => 'rw', isa => 'Elive::Entity::Role|Str',
 	       coerce => 1,
     );
 
+has 'type' => (is => 'rw', isa => 'Int',
+	       documentation => 'Not sure what this is',
+    );
+
 #
 # name change under 9.5
 #
